# https://nixos.wiki/wiki/Java
{ fetchzip,
  stdenv,
  writeShellScript,
  jre,

  version ? "4.5.8",
  hash ? "sha256-HZHNyw+LrxAN4OLueAhyxRG2onPWNMm5MwJDLLzsE2M="
}:

let
  file_name = "stanford-corenlp-${version}.zip";
  url = "http://nlp.stanford.edu/software/${file_name}";
  zip_file = fetchzip { inherit url hash; };
  start_server = writeShellScript "startCoreNLPServer.sh" ''
    PORT=9000

    while getopts ':p:h' opt; do
      case $opt in
        (p) PORT=$OPTARG;;
        (h) echo "$(basename $0) [-p 9000]"
            exit 0
            ;;
      esac
    done

    shift "$((OPTIND - 1))"

    ${jre}/bin/java -mx4g -cp "${zip_file}/*"  edu.stanford.nlp.pipeline.StanfordCoreNLPServer -port $PORT -timeout 15000
  '';
in

stdenv.mkDerivation rec {
  name = "corenlp";
  inherit version;
  phases = "installPhase";
  installPhase = ''
    mkdir -p $out/bin
    cp ${start_server} $out/bin/startCoreNLPServer.sh
  '';
}
